running_text library
Classes
- RunningTextModel
- RunningTextView
-
Running Text widget with data
RunningTextView(
data: RunningTextModel(
"Learn how to find target keywords", "Learn how to find target keywords for any page with our keyword research guide.", "Thanks for using! Follow me for more!") )
Enums
- RunningTextDirection
- Direction of movement of Running Text
- RunningTextFadeSide
- The edges of the Running Text will be blurred